@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: ReportManager.cpp 1497 2007-06-13 07:54:55Z cs $
+ * $Id$
  */
 
 #include "ReportManager.h"
@@ -31,7 +31,6 @@
 
 #include "Project.h"
 #include "HTMLReport.h"
-#include "ICalReport.h"
 #include "CSVReport.h"
 #include "XMLReport.h"
 #include "ExportReport.h"
@@ -223,6 +222,11 @@ ReportManager::updateReportBrowser()
             subTypeIcon =
                 KGlobal::iconLoader()->loadIcon("tj_calendar_report",
                                                 KIcon::Small);
+        else if (strncmp(subType, "MonthlyCalendar",
+                         strlen("MonthlyCalendar")) == 0)
+            subTypeIcon =
+                KGlobal::iconLoader()->loadIcon("tj_calendar_report",
+                                                KIcon::Small);
         else if (strncmp(subType, "Status", strlen("Status")) == 0)
             subTypeIcon =
                 KGlobal::iconLoader()->loadIcon("tj_status_report",
@@ -274,48 +278,7 @@ ReportManager::generateReport(QListViewItem* lvi)
     if (!mr)
         return true;
 
-    bool retVal = true;
-    if (strncmp(mr->getProjectReport()->getType(), "Qt", 2) == 0)
-    {
-        // Nothing to do
-        return true;
-    }
-    else if (strncmp(mr->getProjectReport()->getType(), "CSV", 3) == 0)
-    {
-        CSVReport* csvReport =
-            dynamic_cast<CSVReport*>(mr->getProjectReport());
-        retVal = csvReport->generate();
-    }
-    else if (strncmp(mr->getProjectReport()->getType(), "Export", 6) == 0)
-    {
-        ExportReport* exportReport =
-            dynamic_cast<ExportReport*>(mr->getProjectReport());
-        retVal = exportReport->generate();
-    }
-    else if (strncmp(mr->getProjectReport()->getType(), "HTML", 4) == 0)
-    {
-        HTMLReport* htmlReport =
-            dynamic_cast<HTMLReport*>(mr->getProjectReport());
-        retVal = htmlReport->generate();
-    }
-    else if (strncmp(mr->getProjectReport()->getType(), "ICal", 4) == 0)
-    {
-        ICalReport* icalReport =
-            dynamic_cast<ICalReport*>(mr->getProjectReport());
-        retVal = icalReport->generate();
-    }
-    else if (strncmp(mr->getProjectReport()->getType(), "XML", 3) == 0)
-    {
-        XMLReport* xmlReport =
-            dynamic_cast<XMLReport*>(mr->getProjectReport());
-        retVal = xmlReport->generate();
-    }
-    else
-    {
-        kdDebug() << "Report type " << mr->getProjectReport()->getType()
-            << " not yet supported" << endl;
-        return false;
-    }
+    bool retVal = mr->getProjectReport()->generate();
 
     if (retVal)
         KMessageBox::information(0, i18n("The report '%1' has been generated")
@@ -355,129 +318,134 @@ ReportManager::showReport(QListViewItem* lvi, bool& showReportTab)
          * summary report. The summary report has no report definition, so it
          * can be identified by a 0 pointer. */
         for (std::list<ManagedReportInfo*>::const_iterator
-             mri = reports.begin();
-             mri != reports.end(); ++mri)
+             mri = reports.begin(); mri != reports.end(); ++mri)
             if ((*mri)->getProjectReport() == 0)
+            {
                 mr = *mri;
+                break;
+            }
     }
 
     TjUIReportBase* tjr = mr->getReport();
+    Report *rep = mr->getProjectReport();
+    const char * type = rep ? rep->getType() : "";
+    bool result = true;
     if (tjr == 0)
     {
-        if (mr->getProjectReport() == 0)
+        if (rep == 0)
             tjr = new TjSummaryReport(reportStack, this, project);
-        else if (strcmp(mr->getProjectReport()->getType(), "QtTaskReport") == 0)
-            tjr = new TjTaskReport(reportStack, this, mr->getProjectReport());
-        else if (strcmp(mr->getProjectReport()->getType(),
-                        "QtResourceReport") == 0)
-            tjr = new TjResourceReport(reportStack, this,
-                                       mr->getProjectReport());
-        else if (strncmp(mr->getProjectReport()->getType(), "CSV", 3) == 0)
+        else if (strcmp(type, "QtTaskReport") == 0)
+            tjr = new TjTaskReport(reportStack, this, rep);
+        else if (strcmp(type, "QtResourceReport") == 0)
+            tjr = new TjResourceReport(reportStack, this, rep);
+        else if (strncmp(type, "CSV", 3) == 0)
         {
-            CSVReport* csvReport =
-                dynamic_cast<CSVReport*>(mr->getProjectReport());
-            if (!csvReport->generate())
-                return false;
+            if (!rep->generate())
+                result = false;
             // show the CSV file in preferred CSV handler
             KURL reportUrl =
-                KURL::fromPathOrURL(mr->getProjectReport()->
-                                    getDefinitionFile());
-            reportUrl.setFileName(mr->getProjectReport()->getFileName());
+                KURL::fromPathOrURL(rep->getDefinitionFile());
+            reportUrl.setFileName(rep->getFileName());
 
             changeStatusBar(i18n("Displaying CSV report: '%1'")
-                            .arg(mr->getProjectReport()->getFileName()));
+                            .arg(rep->getFileName()));
             KRun::runURL(reportUrl, "text/x-csv");
-            return true;
         }
-        else if (strncmp(mr->getProjectReport()->getType(), "HTML", 4) == 0)
-            tjr = new TjHTMLReport(reportStack, this, mr->getProjectReport());
-        else if (strncmp(mr->getProjectReport()->getType(), "ICal", 4) == 0)
+        else if (strncmp(type, "HTML", 4) == 0)
+            tjr = new TjHTMLReport(reportStack, this, rep);
+        else if (strncmp(type, "ICal", 4) == 0)
         {
-            ICalReport* icalReport =
-                dynamic_cast<ICalReport*>(mr->getProjectReport());
-            if (!icalReport->generate())
-                return false;
-            // show the TODO list in Korganizer
-            KURL reportUrl =
-                KURL::fromPathOrURL(mr->getProjectReport()->
-                                    getDefinitionFile());
-            reportUrl.setFileName(mr->getProjectReport()->getFileName());
-
-            changeStatusBar(i18n("Displaying iCalendar: '%1'")
-                            .arg(mr->getProjectReport()->getFileName()));
-            KRun::runURL(reportUrl, "text/calendar");
-            return true;
-        }
-        else if (strncmp(mr->getProjectReport()->getType(), "Export", 6) == 0)
-        {
-            // Generate the report file
-            ExportReport* exportReport =
-                dynamic_cast<ExportReport*>(mr->getProjectReport());
-            if (!exportReport->generate())
-                return false;
-
-            // Get the full file name as URL and show it in the editor
-            KURL reportUrl =
-                KURL::fromPathOrURL(mr->getProjectReport()->getFullFileName());
-            if (reportUrl.url().right(4) == ".tjp")
-            {
-                changeStatusBar(i18n("Starting new TaskJuggler for '%1'")
-                    .arg(mr->getProjectReport()->getFileName()));
-                KRun::runURL(reportUrl, "application/x-tjp");
-            }
+            if (!rep->generate())
+                result = false;
             else
             {
-                emit signalEditFile(reportUrl);
-                showReportTab = false;
+                // show the TODO list in Korganizer
+                KURL reportUrl =
+                    KURL::fromPathOrURL(rep->getDefinitionFile());
+                reportUrl.setFileName(rep->getFileName());
+
+                changeStatusBar(i18n("Displaying iCalendar: '%1'")
+                                .arg(rep->getFileName()));
+                KRun::runURL(reportUrl, "text/calendar");
             }
-            return true;
         }
-        else if (strncmp(mr->getProjectReport()->getType(), "XMLReport", 9)
-                 == 0)
+        else if (strncmp(type, "Export", 6) == 0)
         {
-            bool result = mr->getProjectReport()->generate();
+            // Generate the report file
+            if (!rep->generate())
+                result = false;
+            else
+            {
+                // Get the full file name as URL and show it in the editor
+                KURL reportUrl =
+                    KURL::fromPathOrURL(rep->getFullFileName());
+                if (reportUrl.url().right(4) == ".tjp")
+                {
+                    changeStatusBar(i18n("Starting new TaskJuggler for '%1'")
+                                    .arg(rep->getFileName()));
+                    KRun::runURL(reportUrl, "application/x-tjp");
+                }
+                else
+                {
+                    emit signalEditFile(reportUrl);
+                    showReportTab = false;
+                }
+            }
+        }
+        else if (strncmp(type, "XMLReport", 9) == 0)
+        {
+            bool result = rep->generate();
             if (result)
             {
                 KMessageBox::information
                     (mainWindow, i18n("The report '%1' has been generated.")
-                     .arg(mr->getProjectReport()->getFileName()),
+                     .arg(rep->getFileName()),
                      QString::null, "XMLReportGeneratedInfo");
                 changeStatusBar(i18n("The report '%1' has been generated")
-                    .arg(mr->getProjectReport()->getFileName()));
+                    .arg(rep->getFileName()));
             }
             else
                 changeStatusBar(i18n("Could not generated report '%1'")
-                    .arg(mr->getProjectReport()->getFileName()));
-            return result;
+                    .arg(rep->getFileName()));
         }
         else
         {
-            kdDebug() << "Report type " << mr->getProjectReport()->getType()
-                << " not yet supported" << endl;
+            kdDebug() << "Report type " << type << " not yet supported" << endl;
+            result = false;
+        }
+
+        if (!tjr)
+        {
+            /* A report with no widget that can be embedded in the report view
+             * has been selected. We fall back to show the summary report and
+             * unselect the selected browser item. */
+            if (browser->currentItem())
+                browser->setSelected(browser->currentItem(), false);
+            tjr = new TjSummaryReport(reportStack, this, project);
+        }
+
+        connect(tjr, SIGNAL(signalChangeStatusBar(const QString&)),
+                this, SLOT(changeStatusBar(const QString&)));
+        connect(tjr, SIGNAL(signalEditCoreAttributes(CoreAttributes*)),
+                this, SLOT(editCoreAttributes(CoreAttributes*)));
+
+        if (!tjr->generateReport())
+        {
+            delete tjr;
+            if (browser->currentItem())
+                browser->setSelected(browser->currentItem(), false);
             return false;
         }
 
-        if (tjr)
-        {
-            connect(tjr, SIGNAL(signalChangeStatusBar(const QString&)),
-                    this, SLOT(changeStatusBar(const QString&)));
-            connect(tjr, SIGNAL(signalEditCoreAttributes(CoreAttributes*)),
-                    this, SLOT(editCoreAttributes(CoreAttributes*)));
-
-            if (!tjr->generateReport())
-            {
-                delete tjr;
-                return false;
-            }
-
-            reportStack->addWidget(tjr);
-            mr->setReport(tjr);
-        }
+        reportStack->addWidget(tjr);
+        mr->setReport(tjr);
     }
-    if (tjr)
-        reportStack->raiseWidget(tjr);
 
-    return true;
+    // in older versions of KDE, this produces a (seemingly harmless) warning
+    //    ASSERT: "id < (int)d->m_list.count()" in ./kdeui/kactionclasses.cpp (433)
+    reportStack->raiseWidget(tjr);
+
+    return result;
 }
 
 void
