@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: TjObjPosTable.cpp 1315 2006-08-11 21:05:41Z cs $
+ * $Id$
  */
 
 #include "TjObjPosTable.h"
@@ -23,12 +23,15 @@ TjObjPosTable::~TjObjPosTable()
     entries.clear();
 }
 
-void
+TjObjPosTableEntry*
 TjObjPosTable::addEntry(CoreAttributes* ca, CoreAttributes* subCa,
-                        int pos, int height)
+                        int pos, int height, bool alternate)
 {
-    TjObjPosTableEntry* entry = new TjObjPosTableEntry(ca, subCa, pos, height);
+    TjObjPosTableEntry* entry = new TjObjPosTableEntry(ca, subCa, pos, height,
+                                                       alternate);
     entries[generateKey(ca, subCa)] = entry;
+
+    return entry;
 }
 
 int
