@@ -24,8 +24,7 @@ TjPrintResourceReport::initialize()
 {
     // We need those values frequently. So let's store them in a more
     // accessible place.
-    reportElement = dynamic_cast<QtReportElement*>(const_cast<QtResourceReport*>(
-                dynamic_cast<const QtResourceReport*>(reportDef))->getTable());
+    reportElement = dynamic_cast<QtReportElement*>(dynamic_cast<const QtReport*>(reportDef)->getTable());
     scenario = reportElement->getScenario(0);
 }
 
@@ -60,7 +59,7 @@ TjPrintResourceReport::generate()
     for (ResourceListIterator rli(filteredResourceList); *rli; ++rli)
     {
         TjReportRow* row = new TjReportRow(getNumberOfColumns(), index++);
-        row->setCoreAttributes(static_cast<CoreAttributes*>(*rli), 0);
+        row->setCoreAttributes(*rli, 0);
         rows.push_back(row);
 
         generateResourceListRow(row, *rli);
@@ -73,8 +72,7 @@ TjPrintResourceReport::generate()
         for (TaskListIterator tli(filteredTaskList); *tli; ++tli)
         {
             row = new TjReportRow(getNumberOfColumns(), index++);
-            row->setCoreAttributes(static_cast<CoreAttributes*>(*rli),
-                                   static_cast<CoreAttributes*>(*tli));
+            row->setCoreAttributes(*rli, *tli);
             rows.push_back(row);
 
             generateTaskListRow(row, *tli, *rli);
