@@ -28,8 +28,7 @@ TjPrintTaskReport::initialize()
 
     // We need those values frequently. So let's store them in a more
     // accessible place.
-    reportElement = dynamic_cast<QtReportElement*>(const_cast<QtTaskReport*>(
-                dynamic_cast<const QtTaskReport*>(reportDef))->getTable());
+    reportElement = dynamic_cast<QtReportElement*>(dynamic_cast<const QtReport*>(reportDef)->getTable());
     scenario = reportElement->getScenario(0);
 }
 
@@ -64,7 +63,7 @@ TjPrintTaskReport::generate()
     for (TaskListIterator tli(filteredTaskList); *tli; ++tli)
     {
         TjReportRow* row = new TjReportRow(getNumberOfColumns(), index++);
-        row->setCoreAttributes(static_cast<CoreAttributes*>(*tli), 0);
+        row->setCoreAttributes(*tli, 0);
         rows.push_back(row);
 
         generateTaskListRow(row, *tli);
@@ -77,8 +76,7 @@ TjPrintTaskReport::generate()
         for (ResourceListIterator rli(filteredResourceList); *rli; ++rli)
         {
             row = new TjReportRow(getNumberOfColumns(), index++);
-            row->setCoreAttributes(static_cast<CoreAttributes*>(*tli),
-                                   static_cast<CoreAttributes*>(*rli));
+            row->setCoreAttributes(*tli, *rli);
             rows.push_back(row);
 
             generateResourceListRow(row, *rli, *tli);
