@@ -40,6 +40,7 @@
 #include "Project.h"
 #include "Task.h"
 #include "Resource.h"
+#include "Account.h"
 #include "Utility.h"
 #include "ExpressionTree.h"
 #include "Report.h"
@@ -216,7 +217,8 @@ TjReport::event(QEvent* ev)
         setGanttChartColors();
         regenerateChart();
     }
-    else if (ev->type() == QEvent::MouseButtonPress)
+    // Double click facility
+    else if (ev->type() == QEvent::MouseButtonPress || ev->type() == QEvent::MouseButtonDblClick)
         handleMouseEvent(static_cast<QMouseEvent*>(ev));
 
     return QWidget::event(ev);
@@ -270,7 +272,10 @@ TjReport::regenerateChart()
     delete delayTimer;
     delayTimer = 0;
 
+    if (loadingProject) return;
+
     setCursor(KCursor::waitCursor());
+    setLoadingProject(true);
 
     prepareChart();
 
@@ -281,6 +286,7 @@ TjReport::regenerateChart()
     ganttChart->getHeaderCanvas()->update();
     ganttChart->getChartCanvas()->update();
 
+    setLoadingProject(false);
     setCursor(KCursor::arrowCursor());
 }
 
@@ -299,12 +305,14 @@ TjReport::generateTaskListLine(const QtReportElement* reportElement,
     for (QPtrListIterator<TableColumnInfo>
          ci = reportElement->getColumnsIterator(); *ci; ++ci, ++column)
     {
+        const QString& name((*ci)->getName());
+
         /* The name and indices columns are automatically added as first
          * columns, so we will just ignore them if the user has requested them
          * as well. Calendar and chart columns get special treatment as well. */
-        if (indexColumns.find((*ci)->getName()) != indexColumns.end() ||
-            specialColumns.find((*ci)->getName()) != specialColumns.end() ||
-            (*ci)->getName() == "chart")
+        if (indexColumns.find(name) != indexColumns.end() ||
+            specialColumns.find(name) != specialColumns.end() ||
+            name == "chart")
         {
             column--;
             continue;
@@ -314,9 +322,14 @@ TjReport::generateTaskListLine(const QtReportElement* reportElement,
         QPixmap icon;
 
         const TableColumnFormat* tcf =
-            reportElement->getColumnFormat((*ci)->getName());
+            reportElement->getColumnFormat(name);
 
-        if ((*ci)->getName() == "completed")
+        if (name == "accounts")
+        {
+            if (t->getAccount())
+                cellText = t->getAccount()->getId();
+        }
+        else if (name == "completed")
         {
             double calcedCompletionDegree =
                 t->getCalcedCompletionDegree(scenario);
@@ -350,7 +363,7 @@ TjReport::generateTaskListLine(const QtReportElement* reportElement,
                 }
             }
         }
-        else if ((*ci)->getName() == "completedeffort")
+        else if (name == "completedeffort")
         {
             double val = 0.0;
             if (!r && t->isLeaf())
@@ -374,7 +387,7 @@ TjReport::generateTaskListLine(const QtReportElement* reportElement,
                 (reportElement->scaledLoad(val, tcf->realFormat),
                  lvi, tcf->getHAlign() == TableColumnFormat::right);
         }
-        else if ((*ci)->getName() == "cost")
+        else if (name == "cost")
         {
             double val = t->getCredits
                 (scenario, Interval(reportElement->getStart(),
@@ -383,14 +396,14 @@ TjReport::generateTaskListLine(const QtReportElement* reportElement,
                               lvi, tcf->getHAlign() ==
                               TableColumnFormat::right);
         }
-        else if ((*ci)->getName() == "criticalness")
+        else if (name == "criticalness")
         {
             cellText = indent(QString().sprintf("%f",
                                                 t->getCriticalness(scenario)),
                               lvi, tcf->getHAlign() ==
                               TableColumnFormat::right);
         }
-        else if ((*ci)->getName() == "depends")
+        else if (name == "depends")
         {
             for (TaskListIterator it(t->getPreviousIterator()); *it != 0; ++it)
             {
@@ -399,10 +412,10 @@ TjReport::generateTaskListLine(const QtReportElement* reportElement,
                 cellText += (*it)->getId();
             }
         }
-        else if ((*ci)->getName() == "duration")
+        else if (name == "duration")
             cellText = reportElement->scaledDuration
                 (t->getCalcDuration(scenario), tcf->realFormat);
-        else if ((*ci)->getName() == "effort")
+        else if (name == "effort")
         {
             double val = 0.0;
             val = t->getLoad(scenario, Interval(t->getStart(scenario),
@@ -411,15 +424,15 @@ TjReport::generateTaskListLine(const QtReportElement* reportElement,
                 (reportElement->scaledLoad(val, tcf->realFormat),
                  lvi, tcf->getHAlign() == TableColumnFormat::right);
         }
-        else if ((*ci)->getName() == "end")
+        else if (name == "end")
             cellText = time2user(t->getEnd(scenario) + 1,
                                  reportElement->getTimeFormat());
-        else if ((*ci)->getName() == "endbuffer")
+        else if (name == "endbuffer")
             cellText.sprintf("%3.0f", t->getEndBuffer(scenario));
-        else if ((*ci)->getName() == "endbufferstart")
+        else if (name == "endbufferstart")
             cellText = time2user(t->getEndBufferStart(scenario),
                                  reportElement->getTimeFormat());
-        else if ((*ci)->getName() == "follows")
+        else if (name == "follows")
         {
             for (TaskListIterator it(t->getFollowersIterator()); *it != 0; ++it)
             {
@@ -428,21 +441,21 @@ TjReport::generateTaskListLine(const QtReportElement* reportElement,
                 cellText += (*it)->getId();
             }
         }
-        else if ((*ci)->getName() == "id")
+        else if (name == "id")
             cellText = t->getId();
-        else if ((*ci)->getName() == "maxend")
+        else if (name == "maxend")
             cellText = time2user(t->getMaxEnd(scenario),
                                  reportElement->getTimeFormat());
-        else if ((*ci)->getName() == "maxstart")
+        else if (name == "maxstart")
             cellText = time2user(t->getMaxStart(scenario),
                                  reportElement->getTimeFormat());
-        else if ((*ci)->getName() == "minend")
+        else if (name == "minend")
             cellText = time2user(t->getMinEnd(scenario),
                                  reportElement->getTimeFormat());
-        else if ((*ci)->getName() == "minstart")
+        else if (name == "minstart")
             cellText = time2user(t->getMinStart(scenario),
                                  reportElement->getTimeFormat());
-        else if ((*ci)->getName() == "note" && !t->getNote().isEmpty())
+        else if (name == "note" && !t->getNote().isEmpty())
         {
             if (t->getNote().length() > 25 || isRichText(t->getNote()))
                 icon = KGlobal::iconLoader()->
@@ -450,20 +463,20 @@ TjReport::generateTaskListLine(const QtReportElement* reportElement,
             else
                 cellText = t->getNote();
         }
-        else if ((*ci)->getName() == "pathcriticalness")
+        else if (name == "pathcriticalness")
             cellText = indent(QString().sprintf
                               ("%f", t->getPathCriticalness(scenario)),
                               lvi, tcf->getHAlign() ==
                               TableColumnFormat::right);
-        else if ((*ci)->getName() == "priority")
+        else if (name == "priority")
             cellText = indent(QString().sprintf("%d", t->getPriority()),
                               lvi, tcf->getHAlign() ==
                               TableColumnFormat::right);
-        else if ((*ci)->getName() == "projectid")
+        else if (name == "projectid")
             cellText = t->getProjectId() + " (" +
                 reportElement->getReport()->getProject()->getIdIndex
                 (t->getProjectId()) + ")";
-        else if ((*ci)->getName() == "profit")
+        else if (name == "profit")
         {
             double val = t->getCredits
                 (scenario, Interval(reportElement->getStart(),
@@ -475,7 +488,7 @@ TjReport::generateTaskListLine(const QtReportElement* reportElement,
                               lvi, tcf->getHAlign() ==
                               TableColumnFormat::right);
         }
-        else if ((*ci)->getName() == "remainingeffort")
+        else if (name == "remainingeffort")
         {
             double val = 0.0;
             if (!r && t->isLeaf())
@@ -499,7 +512,7 @@ TjReport::generateTaskListLine(const QtReportElement* reportElement,
                 (reportElement->scaledLoad(val, tcf->realFormat),
                  lvi, tcf->getHAlign() == TableColumnFormat::right);
         }
-        else if ((*ci)->getName() == "resources")
+        else if (name == "resources")
         {
             for (ResourceListIterator rli
                  (t->getBookedResourcesIterator(scenario)); *rli != 0; ++rli)
@@ -510,12 +523,12 @@ TjReport::generateTaskListLine(const QtReportElement* reportElement,
                 cellText += (*rli)->getName();
             }
         }
-        else if ((*ci)->getName() == "responsible")
+        else if (name == "responsible")
         {
             if (t->getResponsible())
                 cellText = t->getResponsible()->getName();
         }
-        else if ((*ci)->getName() == "revenue")
+        else if (name == "revenue")
         {
             double val = t->getCredits
                 (scenario, Interval(reportElement->getStart(),
@@ -524,21 +537,21 @@ TjReport::generateTaskListLine(const QtReportElement* reportElement,
                               lvi, tcf->getHAlign() ==
                               TableColumnFormat::right);
         }
-        else if ((*ci)->getName() == "scheduling")
+        else if (name == "scheduling")
             cellText = t->getSchedulingText();
-        else if ((*ci)->getName() == "start")
+        else if (name == "start")
             cellText = time2user(t->getStart(scenario),
                                  reportElement->getTimeFormat());
-        else if ((*ci)->getName() == "startbuffer")
+        else if (name == "startbuffer")
             cellText.sprintf("%3.0f", t->getStartBuffer(scenario));
-        else if ((*ci)->getName() == "startbufferend")
+        else if (name == "startbufferend")
             cellText = time2user(t->getStartBufferEnd(scenario),
                                  reportElement->getTimeFormat());
-        else if ((*ci)->getName() == "status")
+        else if (name == "status")
         {
             cellText = t->getStatusText(scenario);
         }
-        else if ((*ci)->getName() == "statusnote")
+        else if (name == "statusnote")
         {
             if (t->getStatusNote(scenario).length() > 25 ||
                 isRichText(t->getStatusNote(scenario)))
@@ -548,7 +561,7 @@ TjReport::generateTaskListLine(const QtReportElement* reportElement,
                 cellText = t->getStatusNote(scenario);
         }
         else
-            generateCustomAttribute(t, (*ci)->getName(), cellText, icon);
+            generateCustomAttribute(t, name, cellText, icon);
 
         lvi->setText(column, cellText);
         if (!icon.isNull())
@@ -570,12 +583,14 @@ TjReport::generateResourceListLine(const QtReportElement* reportElement,
     for (QPtrListIterator<TableColumnInfo>
          ci = reportElement->getColumnsIterator(); *ci; ++ci, ++column)
     {
+        const QString& name((*ci)->getName());
+
         /* The name and indices columns are automatically added as first
          * columns, so we will just ignore them if the user has requested them
          * as well. Calendar and chart columns get special treatment as well. */
-        if (indexColumns.find((*ci)->getName()) != indexColumns.end() ||
-            specialColumns.find((*ci)->getName()) != specialColumns.end() ||
-            (*ci)->getName() == "chart")
+        if (indexColumns.find(name) != indexColumns.end() ||
+            specialColumns.find(name) != specialColumns.end() ||
+            name == "chart")
         {
             column--;
             continue;
@@ -584,9 +599,9 @@ TjReport::generateResourceListLine(const QtReportElement* reportElement,
         QString cellText;
         QPixmap icon;
         const TableColumnFormat* tcf =
-            reportElement->getColumnFormat((*ci)->getName());
+            reportElement->getColumnFormat(name);
 
-        if ((*ci)->getName() == "cost")
+        if (name == "cost")
         {
             double val = r->getCredits
                 (scenario, Interval(reportElement->getStart(),
@@ -595,11 +610,11 @@ TjReport::generateResourceListLine(const QtReportElement* reportElement,
                               lvi, tcf->getHAlign() ==
                               TableColumnFormat::right);
         }
-        else if ((*ci)->getName() == "efficiency")
+        else if (name == "efficiency")
         {
             cellText = QString().sprintf("%.1lf", r->getEfficiency());
         }
-        else if ((*ci)->getName() == "effort")
+        else if (name == "effort")
         {
             double val = 0.0;
             if (t)
@@ -616,7 +631,7 @@ TjReport::generateResourceListLine(const QtReportElement* reportElement,
                 (reportElement->scaledLoad(val, tcf->realFormat), lvi,
                  tcf->getHAlign() == TableColumnFormat::right);
         }
-        else if ((*ci)->getName() == "freeload")
+        else if (name == "freeload")
         {
             if (!t)
             {
@@ -629,11 +644,11 @@ TjReport::generateResourceListLine(const QtReportElement* reportElement,
                      tcf->getHAlign() == TableColumnFormat::right);
             }
         }
-        else if ((*ci)->getName() == "id")
+        else if (name == "id")
         {
             cellText = r->getFullId();
         }
-        else if ((*ci)->getName() == "maxeffort")
+        else if (name == "maxeffort")
         {
             const UsageLimits* limits = r->getLimits();
             if (limits == 0)
@@ -660,17 +675,17 @@ TjReport::generateResourceListLine(const QtReportElement* reportElement,
                 }
             }
         }
-        else if ((*ci)->getName() == "projectids")
+        else if (name == "projectids")
             cellText = r->getProjectIDs
                 (scenario, Interval(reportElement->getStart(),
                                     reportElement->getEnd()));
-        else if ((*ci)->getName() == "rate")
+        else if (name == "rate")
         {
             cellText = indent(tcf->realFormat.format(r->getRate(), false),
                               lvi, tcf->getHAlign() ==
                               TableColumnFormat::right);
         }
-        else if ((*ci)->getName() == "revenue")
+        else if (name == "revenue")
         {
             double val = r->getCredits
                 (scenario, Interval(reportElement->getStart(),
@@ -679,7 +694,7 @@ TjReport::generateResourceListLine(const QtReportElement* reportElement,
                               lvi, tcf->getHAlign() ==
                               TableColumnFormat::right);
         }
-        else if ((*ci)->getName() == "utilization")
+        else if (name == "utilization")
         {
             if (!t)
             {
@@ -701,7 +716,7 @@ TjReport::generateResourceListLine(const QtReportElement* reportElement,
             }
         }
         else
-            generateCustomAttribute(r, (*ci)->getName(), cellText, icon);
+            generateCustomAttribute(r, name, cellText, icon);
 
         lvi->setText(column, cellText);
         if (!icon.isNull())
@@ -936,7 +951,7 @@ TjReport::listClicked(QListViewItem* lvi, const QPoint&, int column)
     // The first column is always the name and the second column is the hidden
     // sort index. Both are not in the TCI table. All clickable columns have
     // an icon.
-    if (!lvi || column <= 1 || !lvi->pixmap(column))
+    if (loadingProject || !lvi || column <= 1 || !lvi->pixmap(column))
         return;
 
     CoreAttributes* ca = lvi2caDict[QString().sprintf("%p", lvi)];
@@ -1020,7 +1035,7 @@ TjReport::listHeaderClicked(int)
 void
 TjReport::doPopupMenu(QListViewItem* lvi, const QPoint& pos, int)
 {
-    if (!lvi)
+    if (loadingProject || !lvi)
         return;
 
     CoreAttributes* ca = lvi2caDict[QString().sprintf("%p", lvi)];
@@ -1087,12 +1102,43 @@ TjReport::showTaskDetails(const Task* task)
         text += i18n("<b>Note:</b> %1<br/>").arg(task->getNote());
     }
 
+    // Display status note if not empty.
+    if (!task->getStatusNote(scenario).isEmpty())
+    {
+        if (!text.isEmpty())
+            text += "<hr/>";
+        text += i18n("<b>Status note:</b> %1<br/>")
+            .arg(task->getStatusNote(scenario));
+    }
+
     if (task->isMilestone())
     {
         if (!text.isEmpty())
             text += "<hr/>";
         text += i18n("<b>Date:</b> %1<br/>")
-            .arg(time2tjp(task->getStart(scenario)));
+            .arg(time2user(task->getStart(scenario), task->getProject()->getTimeFormat()));
+
+        // Display min and max start and end dates.
+        if (task->getMinStart(scenario)!=0)
+        {
+            text += i18n("<b>Min Start:</b> %1<br/>")
+                .arg(time2user(task->getMinStart(scenario), task->getProject()->getTimeFormat()));
+        }
+        if (task->getMinEnd(scenario)!=0)
+        {
+            text += i18n("<b>Min End:</b> %1<br/>")
+                .arg(time2user(task->getMinEnd(scenario), task->getProject()->getTimeFormat()));
+        }
+        if (task->getMaxStart(scenario)!=0)
+        {
+            text += i18n("<b>Max Start:</b> %1<br/>")
+                .arg(time2user(task->getMaxStart(scenario), task->getProject()->getTimeFormat()));
+        }
+        if (task->getMaxEnd(scenario)!=0)
+        {
+            text += i18n("<b>Max End :</b> %1<br/>")
+                .arg(time2user(task->getMaxEnd(scenario), task->getProject()->getTimeFormat()));
+        }
     }
     else
     {
@@ -1101,8 +1147,8 @@ TjReport::showTaskDetails(const Task* task)
         text += i18n("<b>Start:</b> %1<br/>"
                      "<b>End:</b> %2<br/>"
                      "<b>Status:</b> %3<br/>")
-            .arg(time2tjp(task->getStart(scenario)))
-            .arg(time2tjp(task->getEnd(scenario) + 1))
+            .arg(time2user(task->getStart(scenario), task->getProject()->getTimeFormat()))
+            .arg(time2user(task->getEnd(scenario) + 1, task->getProject()->getTimeFormat()))
             .arg(task->getStatusText(scenario));
 
         if (task->getEffort(scenario) > 0.0)
@@ -1139,10 +1185,6 @@ TjReport::showTaskDetails(const Task* task)
                           report->getNumberFormat(), true, false));
             }
         }
-
-        if (!task->getStatusNote(scenario).isEmpty())
-            text += i18n("<b>Note:</b> %1<br/>")
-                .arg(task->getStatusNote(scenario));
     }
 
     QString predecessors;
@@ -1228,6 +1270,67 @@ TjReport::showResourceDetails(Resource* resource)
         text += generateJournal(resource->getJournalIterator());
     }
 
+    // Display of vacations
+    text += i18n("<hr/><b>Vacations:</b>");
+    {
+        QPtrListIterator<Interval> vli(resource->getVacationListIterator());
+
+        if (*vli != 0)
+        {
+            text += i18n("<p/><p>Personnal vacations:</p>");
+            for (QPtrListIterator<Interval> vli(resource->getVacationListIterator()); *vli != 0; ++vli)
+            {
+                if (sameTimeNextDay((*vli)->getStart()) == 1 + (*vli)->getEnd()
+                    && secondsOfDay((*vli)->getStart()) == 0 )
+                    text += i18n("<li>%1</li>")
+                        .arg(time2user((*vli)->getStart(), resource->getProject()->getTimeFormat()));
+                else
+                    text += i18n("<li>%1 - %2</li>")
+                        .arg(time2user((*vli)->getStart(), resource->getProject()->getTimeFormat()))
+                        .arg(time2user((*vli)->getEnd(), resource->getProject()->getTimeFormat()));
+            }
+        }
+        else
+        {
+            text += i18n("<p>No personnal vacations.</p>");
+        }
+    }
+
+    {
+        VacationList::Iterator vli(resource->getProject()->getVacationListIterator());
+        if (*vli != 0)
+        {
+            text += i18n("<p>Global vacations:</p>");
+            // Because the global vacation list is in reverse order and we want to display in original order, we use a temp string.
+            QString tmpText;
+            for ( ; *vli != 0; ++vli)
+            {
+                // Only display one day when vacation duration is one day, starting at midnight.
+                if (sameTimeNextDay((*vli)->getStart()) == 1 + (*vli)->getEnd()
+                    && secondsOfDay((*vli)->getStart()) == 0 )
+                {
+                    tmpText = i18n("<li>%1 : %2</li>")
+                        .arg(time2user((*vli)->getStart(), resource->getProject()->getTimeFormat()))
+                        .arg((*vli)->getName()) + tmpText;
+                }
+                // Otherwise, display the two vacation dates in user datetime format.
+                else
+                {
+                    tmpText = i18n("<li>%1 - %2 : %3</li>")
+                        .arg(time2user((*vli)->getStart(), resource->getProject()->getTimeFormat()))
+                        .arg(time2user((*vli)->getEnd(), resource->getProject()->getTimeFormat()))
+                        .arg((*vli)->getName()) + tmpText;
+                }
+            }
+            text += tmpText;
+        }
+        else
+        {
+            text += i18n("<p>No global vacations:.</p>");
+        }
+    }
+    text += "<hr/>";
+
     richTextDisplay->textDisplay->setText(text);
     richTextDisplay->show();
 }
@@ -1237,10 +1340,12 @@ TjReport::generateRTCustomAttributes(const CoreAttributes* ca) const
 {
     QDict<CustomAttribute> caDict = ca->getCustomAttributeDict();
 
-    QString text = "<hr/>";
+    QString text = "";
     if (caDict.isEmpty())
         return text;
 
+    text += "<hr/>";
+
     for (QDictIterator<CustomAttribute> cadi(caDict); cadi.current(); ++cadi)
     {
         text += "<b>" + cadi.currentKey() + ":</b> ";
@@ -1306,10 +1411,31 @@ TjReport::handleMouseEvent(const QMouseEvent* ev)
 {
     QPoint pos;
     QListViewItem* lvi = getChartItemBelowCursor(pos);
-    if (!lvi)
+    if (loadingProject || !lvi)
         return;
 
-    if (ev->button() == Qt::LeftButton)
+    CoreAttributes* ca = lvi2caDict[QString().sprintf("%p", lvi)];
+
+    // Middle button facility
+    if (ev->button() == Qt::MidButton)
+    {
+        emit signalEditCoreAttributes(ca);
+    }
+    // Double click
+    else if (ev->type() == QEvent::MouseButtonDblClick)
+    {
+        if (ca->getType() == CA_Task)
+        {
+            Task* t = dynamic_cast<Task*>(ca);
+            if (t) showTaskDetails(t);
+        }
+        else
+        {
+            Resource* r = dynamic_cast<Resource*>(ca);
+            if (r) showResourceDetails(r);
+        }
+    }
+    else if (ev->button() == Qt::LeftButton)
         listView->setSelected(lvi, true);
     else if (ev->button() == Qt::RightButton)
         doPopupMenu(lvi, QCursor::pos(), 0);
@@ -1420,11 +1546,13 @@ TjReport::getChartItemBelowCursor(QPoint& pos)
 void
 TjReport::zoomTo(const QString& label)
 {
-    if (!isVisible())
+    if (loadingProject || !isVisible())
         return;
 
     time_t x = ganttChart->x2time(ganttChartView->contentsX());
     int y = ganttChartView->contentsY();
+    if (x <= 0 && y <= 0)
+        return;
 
     if (!ganttChart->zoomTo(label))
         return;
@@ -1442,7 +1570,7 @@ TjReport::zoomTo(const QString& label)
 void
 TjReport::zoomIn()
 {
-    if (!isVisible())
+    if (loadingProject || !isVisible())
         return;
 
     time_t x = ganttChart->x2time(ganttChartView->contentsX());
@@ -1465,7 +1593,7 @@ TjReport::zoomIn()
 void
 TjReport::zoomOut()
 {
-    if (!isVisible())
+    if (loadingProject || !isVisible())
         return;
 
     time_t x = ganttChart->x2time(ganttChartView->contentsX());
