@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: TjResourceReport.cpp 1497 2007-06-13 07:54:55Z cs $
+ * $Id$
  */
 
 #include "TjResourceReport.h"
@@ -44,7 +44,7 @@ TjResourceReport::newPrintReport(KPrinter* pr)
     return new TjPrintResourceReport(report, pr);
 }
 
-const QtReportElement*
+QtReportElement*
 TjResourceReport::getReportElement() const
 {
     return reportElement;
@@ -76,6 +76,7 @@ TjResourceReport::generateList()
     if (!reportElement->filterResourceList
         (resourceList, 0, reportElement->getHideResource(), 0))
         return false;
+    reportElement->sortResourceList(resourceList);
 
     if (resourceList.isEmpty())
         return true;
@@ -154,7 +155,7 @@ TjResourceReport::generateList()
                 /* We iterate through the filtered task list and check whether
                  * we need to insert the tasks in a tree or not. */
                 int parentIdx = 0;
-                QListViewItem* lvi;
+                KListViewItem* lvi;
                 if ((*tli)->getParent() &&
                     reportElement->showTaskTree() &&
                     (parentIdx =
@@ -163,7 +164,7 @@ TjResourceReport::generateList()
                     // Find the corresponding parent LVI and insert the task
                     // as a child of it.
                     CoreAttributes* parent = filteredTaskList.at(parentIdx);
-                    QListViewItem* parentLvi =
+                    KListViewItem* parentLvi =
                         ca2lviDict[QString("t:") + (*rli)->getId() +
                         ":" + parent->getId()];
                     lvi = new KListViewItem(parentLvi, (*tli)->getName());
@@ -206,7 +207,7 @@ TjResourceReport::generateList()
             for (TaskListIterator tli((*rli)->getTaskListIterator(scenario));
                  *tli; ++tli)
             {
-                QListViewItem* lvi = ca2lviDict[QString("t:") +
+                KListViewItem* lvi = ca2lviDict[QString("t:") +
                     (*rli)->getId() + ":" + (*tli)->getId()];
                 // Some tasks may be hidden, so we have to ignore those.
                 if (lvi)
