@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: TjTaskReport.cpp 1497 2007-06-13 07:54:55Z cs $
+ * $Id$
  */
 
 #include "TjTaskReport.h"
@@ -44,7 +44,7 @@ TjTaskReport::newPrintReport(KPrinter* pr)
     return new TjPrintTaskReport(report, pr);
 }
 
-const QtReportElement*
+QtReportElement*
 TjTaskReport::getReportElement() const
 {
     return reportElement;
@@ -73,19 +73,9 @@ TjTaskReport::generateList()
     scenario = reportElement->getScenario(0);
     taskList = report->getProject()->getTaskList();
 
-    // QListView can hide subtasks. So we feed the list with all tasks first
-    // and then later close those items that we want to roll up. This
-    // expression means "roll-up none".
-    ExpressionTree* et = new ExpressionTree;
-    et->setTree("0", report->getProject());
-
     if (!reportElement->filterTaskList(taskList, 0,
-                                       reportElement->getHideTask(), et))
-    {
-        delete et;
+                                       reportElement->getHideTask(), 0))
         return false;
-    }
-    delete et;
 
     reportElement->sortTaskList(taskList);
 
@@ -153,7 +143,7 @@ TjTaskReport::generateList()
                                           getBookedResourcesIterator(scenario));
                  *rli; ++rli)
             {
-                QListViewItem* lvi =
+                KListViewItem* lvi =
                     new KListViewItem(newLvi, (*rli)->getName());
                 lvi->setPixmap(0, KGlobal::iconLoader()->
                                loadIcon("tj_resource", KIcon::Small));
@@ -172,7 +162,7 @@ TjTaskReport::generateList()
     // columns.
     for (TaskListIterator tli(taskList); *tli; ++tli)
     {
-        QListViewItem* lvi = ca2lviDict[QString("t:") + (*tli)->getId()];
+        KListViewItem* lvi = ca2lviDict[QString("t:") + (*tli)->getId()];
         generateTaskListLine(reportElement, *tli, lvi);
         if (!(*tli)->isContainer() && !(*tli)->isMilestone())
         {
@@ -180,7 +170,7 @@ TjTaskReport::generateList()
                                           getBookedResourcesIterator(scenario));
                  *rli; ++rli)
             {
-                QListViewItem* lvi = ca2lviDict[QString("r:") +
+                KListViewItem* lvi = ca2lviDict[QString("r:") +
                     (*tli)->getId() + ":" + (*rli)->getId()];
                 // Make sure that the resource is not hidden.
                 if (lvi)
