@@ -415,7 +415,8 @@ TaskJugglerView::pickTemplateFile(const QString& extension)
     // Select the first entry in the list and enable the OK button.
     if (selector->templateList->firstChild())
     {
-        selector->templateList->firstChild()->setSelected(true);
+        selector->templateList->setSelected
+            (selector->templateList->firstChild(), true);
         selector->buttonOk->setEnabled(true);
     }
 
@@ -1089,7 +1090,7 @@ void
 TaskJugglerView::reportListClicked(int button, QListViewItem* lvi,
                                    const QPoint& p, int col)
 {
-    if (!lvi)
+    if (loadingProject || !lvi)
         return;
 
     bool errors = false;
