@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: CoreAttributes.h 1428 2007-03-17 15:24:21Z cs $
+ * $Id$
  */
 
 #ifndef _CoreAttributes_h_
@@ -56,6 +56,7 @@ public:
 
     void setHierarchIndex(uint no);
     QString getHierarchIndex() const;
+    QString getHierarchLevel() const;
 
     Project* getProject() const { return project; }
 
@@ -78,9 +79,8 @@ public:
     FlagList getFlagList() const { return flags; }
 
     bool hasSameAncestor(const CoreAttributes* c) const;
-    bool isDescendentOf(const CoreAttributes* c) const;
+    bool isDescendantOf(const CoreAttributes* c) const;
     bool isParentOf(const CoreAttributes* c) const;
-    bool isChildOf(const CoreAttributes* c) const;
 
     bool isRoot() const { return parent == 0; }
     bool isLeaf() const;
