@@ -894,6 +894,14 @@ HTMLReportElement::genCellEmpty(TableCellInfo* tci)
     genCell("", tci, true);
 }
 
+void
+HTMLReportElement::genCellAccounts(TableCellInfo* tci)
+{
+    genCell(QString().sprintf("%s", tci->tli->task->getAccount() ?
+                              tci->tli->task->getAccount()->getId().latin1() :
+                              ""), tci, true);
+}
+
 void
 HTMLReportElement::genCellSequenceNo(TableCellInfo* tci)
 {
