@@ -44,22 +44,22 @@ public:
     void setCoreAttributes(CoreAttributes* c) { ca = c; }
     CoreAttributes* getCoreAttributes() const { return ca; }
 
-    void setScenario(Scenario* s) { ca = static_cast<CoreAttributes*>(s); }
+    void setScenario(Scenario* s) { ca = s; }
     Scenario* getScenario() const;
 
     void setWeekday(int day) { weekday = day; }
     int getWeekday() const { return weekday; }
 
-    void setShift(Shift* s) { ca = static_cast<CoreAttributes*>(s); }
+    void setShift(Shift* s) { ca = s; }
     Shift* getShift() const;
 
-    void setResource(Resource* r) { ca = static_cast<CoreAttributes*>(r); }
+    void setResource(Resource* r) { ca = r; }
     Resource* getResource() const;
 
-    void setAccount(Account* a) { ca = static_cast<CoreAttributes*>(a); }
+    void setAccount(Account* a) { ca = a; }
     Account* getAccount() const;
 
-    void setTask(Task* t) { ca = static_cast<CoreAttributes*>(t); }
+    void setTask(Task* t) { ca = t; }
     Task* getTask() const;
 
     void setScenarioIndex(int i) { scenarioIndex = i; }
