@@ -8,7 +8,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: Project.cpp 1497 2007-06-13 07:54:55Z cs $
+ * $Id$
  */
 
 #include "Project.h"
@@ -60,7 +60,7 @@ Project::Project() :
     dailyWorkingHours(8.0),
     yearlyWorkingDays(260.714),
     workingHours(),
-    scheduleGranularity(ONEHOUR),
+    scheduleGranularity(suggestTimingResolution()),
     allowedFlags(),
     projectIDs(),
     currentId(),
@@ -80,7 +80,6 @@ Project::Project() :
     accountAttributes(),
     xmlreport(0),
     reports(),
-    interactiveReports(),
     sourceFiles(),
     breakFlag(false)
 {
@@ -389,22 +388,22 @@ Project::getAccountAttribute(const QString& id) const
 }
 
 bool
-Project::isWorkingDay(time_t d) const
+Project::isWorkingDay(time_t wd) const
 {
-    return !(workingHours[dayOfWeek(d, false)]->isEmpty() ||
-             isVacation(d));
+    return !(workingHours[dayOfWeek(wd, false)]->isEmpty() ||
+             isVacation(wd));
 }
 
 bool
-Project::isWorkingTime(time_t d) const
+Project::isWorkingTime(time_t wd) const
 {
-    if (isVacation(d))
+    if (isVacation(wd))
         return false;
 
-    int dow = dayOfWeek(d, false);
+    int dow = dayOfWeek(wd, false);
     for (QPtrListIterator<Interval> ili(*(workingHours[dow])); *ili != 0; ++ili)
     {
-        if ((*ili)->contains(secondsOfDay(d)))
+        if ((*ili)->contains(secondsOfDay(wd)))
             return true;
     }
     return false;
@@ -442,7 +441,24 @@ Project::calcWorkingDays(const Interval& iv) const
 double
 Project::convertToDailyLoad(long secs) const
 {
-    return ((double) secs / (dailyWorkingHours * ONEHOUR));
+    return (((double) secs) / (dailyWorkingHours * ONEHOUR));
+}
+
+double
+Project::quantizeLoad(double load) const
+{
+    return load;
+    return ((double) (((long) (load * dailyWorkingHours * (double) ONEHOUR)) /
+                               scheduleGranularity)) /
+                      ((dailyWorkingHours * (double) ONEHOUR)) *
+                       (double) scheduleGranularity;
+}
+
+long int
+Project::convertToSlots(double effort) const
+{
+    return ((long int) ((effort * dailyWorkingHours * (double) ONEHOUR)) /
+            scheduleGranularity);
 }
 
 void
@@ -746,6 +762,7 @@ Project::schedule(int sc)
         done = true;
         time_t slot = 0;
         int priority = 0;
+        double pathCriticalness = 0.0;
         Task::SchedulingInfo schedulingInfo = Task::ASAP;
 
         /* The task list is sorted by priority. The priority decreases towards
@@ -760,15 +777,18 @@ Project::schedule(int sc)
                 /* No time slot has been set yet. Check if this task can be
                  * scheduled and provides a suggestion. */
                 slot = (*tli)->nextSlot(scheduleGranularity);
-                priority = (*tli)->getPriority();
-                schedulingInfo = (*tli)->getScheduling();
                 /* If not, try the next task. */
                 if (slot == 0)
                     continue;
+                priority = (*tli)->getPriority();
+                pathCriticalness = (*tli)->getPathCriticalness(sc);
+                schedulingInfo = (*tli)->getScheduling();
 
                 if (DEBUGPS(4))
-                    qDebug("Task '%s' (Prio %d) requests slot %s",
+                    qDebug("Task '%s' (Prio %d, Direction: %d) requests "
+                           "slot %s",
                            (*tli)->getId().latin1(), (*tli)->getPriority(),
+                           (*tli)->getScheduling(),
                            time2ISO(slot).latin1());
                 /* If the task wants a time slot outside of the project time
                  * frame, we flag this task as a runaway and go to the next
@@ -785,12 +805,12 @@ Project::schedule(int sc)
             done = false;
             /* Each task has a scheduling direction (forward or backward)
              * depending on it's constrains. The task with the highest
-             * priority determins the time slot and hence the scheduling
-             * direction. Since tasks that have the other direction cannot the
-             * scheduled then, we have to stop this run as soon as we hit a
-             * task that runs in the other direction. If we would not do this,
-             * tasks with lower priority would grab resources form tasks with
-             * higher priority. */
+             * priority/pathCriticalness determins the time slot and hence the
+             * scheduling direction. Since tasks that have the other direction
+             * cannot the scheduled then, we have to stop this run as soon as
+             * we hit a task that runs in the other direction. If we would not
+             * do this, tasks with lower priority/pathCriticalness  would grab
+             * resources form tasks with higher priority. */
             if ((*tli)->getScheduling() != schedulingInfo &&
                 !(*tli)->isMilestone())
             {
@@ -802,8 +822,11 @@ Project::schedule(int sc)
             }
             /* We must avoid that lower priority tasks get resources even
              * though there are higher priority tasks that are ready to be
-             * scheduled but have a non-adjacent last slot. */
-            if ((*tli)->getPriority() < priority)
+             * scheduled but have a non-adjacent last slot. If two tasks have
+             * the same priority the pathCriticalness is being used. */
+            if ((*tli)->getPriority() < priority ||
+                ((*tli)->getPriority() == priority &&
+                 (*tli)->getPathCriticalness(sc) < pathCriticalness))
                 break;
 
             // Schedule this task for the current time slot.
@@ -843,6 +866,7 @@ Project::schedule(int sc)
     if (runAwayFound)
         for (TaskListIterator tli(taskList); *tli != 0; ++tli)
             if ((*tli)->isRunaway())
+            {
                 if ((*tli)->getScheduling() == Task::ASAP)
                     (*tli)->errorMessage
                         (i18n("End of task '%1' does not fit into the "
@@ -854,6 +878,7 @@ Project::schedule(int sc)
                         (i18n("Start of task '%1' does not fit into the "
                               "project time frame. Try using an earlier "
                               "project start date.").arg((*tli)->getId()));
+            }
 
     if (TJMH.getErrors() == oldErrors)
         setProgressBar(100, 100);
