@@ -7,12 +7,13 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: XMLReport.cpp 1497 2007-06-13 07:54:55Z cs $
+ * $Id$
  */
 
 #include "XMLReport.h"
 
 #include <zlib.h>
+#include <unistd.h>
 
 #include <qmap.h>
 
@@ -49,7 +50,7 @@ typedef enum TADs {
     TA_STATUS,
     TA_STATUSNOTE,
     TA_ACCOUNT
-};
+} TADs;
 
 XMLReport::XMLReport(Project* p, const QString& f,
                            const QString& df, int dl) :
@@ -544,8 +545,7 @@ XMLReport::generateTask(QDomElement* parentEl, TaskList& filteredTaskList,
 
     QString taskId = task->getId();
     if (!taskRoot.isEmpty())
-        taskId = taskId.right(taskId.length() - 1 -
-                              taskRoot.length());
+        taskId = stripTaskRoot(taskId);
     genTextAttr(&el, "id", taskId);
     genTextAttr(&el, "name", task->getName());
     genTextAttr(&el, "projectId", task->getProjectId());
@@ -597,9 +597,9 @@ XMLReport::generateTask(QDomElement* parentEl, TaskList& filteredTaskList,
                 break;
             case TA_DEPENDS:
                 generateDepList(&el, filteredTaskList, task,
-                                task->getDependsIterator(), "depends");
+                                task->getDependsIterator(), true);
                 generateDepList(&el, filteredTaskList, task,
-                                task->getPrecedesIterator(), "precedes");
+                                task->getPrecedesIterator(), false);
                 break;
             case TA_ACCOUNT:
                 if (task->getAccount())
@@ -639,6 +639,7 @@ XMLReport::generateTask(QDomElement* parentEl, TaskList& filteredTaskList,
             genDateElement(&scEl, "start", task->getStart(*it));
         if (task->getEnd(*it) && !task->isMilestone())
             genDateElement(&scEl, "end", task->getEnd(*it) + 1);
+        genLongAttr(&scEl, "criticalpath", task->isOnCriticalPath(*it) ? 1 : 0);
         genLongAttr(&scEl, "scheduled", task->getScheduled(*it) ? 1 : 0);
 
         for (QStringList::Iterator atIt = taskAttributes.begin();
@@ -713,9 +714,8 @@ bool
 XMLReport::generateDepList(QDomElement* parentEl, TaskList& filteredTaskList,
                            const Task* task,
                            QPtrListIterator<TaskDependency> depIt,
-                           const char* tag)
+                           bool prev)
 {
-    bool prev = (tag == "depends");
     for ( ; *depIt != 0; ++depIt)
     {
         /* Save current list item since findRef() modifies
@@ -726,7 +726,7 @@ XMLReport::generateDepList(QDomElement* parentEl, TaskList& filteredTaskList,
               (prev ? task->getParent()->hasPrevious((*depIt)->getTaskRef()) :
                task->getParent()->hasFollower((*depIt)->getTaskRef()))))
         {
-            QDomElement te= doc->createElement(tag);
+            QDomElement te= doc->createElement(prev ? "depends" : "precedes");
             /* Putting the task ID as PCDATA in the depends/precedes element
              * was a mistake. We now store this information as 'task'
              * attribute. The PCDATA is now deprecated and should no longer be
@@ -736,7 +736,8 @@ XMLReport::generateDepList(QDomElement* parentEl, TaskList& filteredTaskList,
                            (stripTaskRoot(((*depIt)->getTaskRef())->getId())));
             parentEl->appendChild(te);
 
-            genTextAttr(&te, "task", (*depIt)->getTaskRef()->getId());
+            genTextAttr(&te, "task",
+                        stripTaskRoot((*depIt)->getTaskRef()->getId()));
 
             for (int sc = 0; sc < project->getMaxScenarios(); ++sc)
                 if ((*depIt)->getGapDuration(sc) != 0 ||
