@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: XMLReport.h 1464 2007-04-09 16:48:44Z cs $
+ * $Id$
  */
 #ifndef _XMLReport_h_
 #define _XMLReport_h_
@@ -65,8 +65,7 @@ private:
     bool generateTask(QDomElement* parentEl, TaskList& ftl, const Task* task);
     bool generateDepList(QDomElement* el, TaskList& filteredTaskList,
                          const Task* task,
-                         QPtrListIterator<TaskDependency> dl,
-                         const char* tag);
+                         QPtrListIterator<TaskDependency> dl, bool prev);
     bool generateCustomAttributeValue(QDomElement* parentEl,
                                       const QString& id,
                                       const CoreAttributes* property);
